Shift to boost asio library

This commit shifts vpd manager from sdbusplus event loop to
boost io_context event loop.
The shift was done to have a more flexible way to perform
async Dbus calls.
For example read/write of vpd data can be performed
asynchronously.

It also removes dependency of Manager class on the interface
class created as a part of Phosphor-Dbus-Interface repo.

Test:
- Introspect com.ibm.VPD.Manager /com/ibm/VPD/Manager to ensure
that all the methods exposed under com.ibm.VPD.Manager interface
matches to the ones documented under PDI repo.

- Make DBus call to each of the exposed api to ensure that the
funcation calls are working fine.

-To ensure bios handler call back is working.
Stop vpd-manager service.
Stop pldm service.
Start vpd-manager service
Start pldm service.
Should recieve callback.

-To ensure gpio call back
std::cout were added to callback function being trigerred on
timer expiration and the same were verified in journal.

Signed-off-by: Sunny Srivastava <sunnsr25@in.ibm.com>
Change-Id: I00640f64de487d5244e8be2e7a3f3d63a013644e
diff --git a/vpd-manager/bios_handler.hpp b/vpd-manager/bios_handler.hpp
index 985daa7..dda120c 100644
--- a/vpd-manager/bios_handler.hpp
+++ b/vpd-manager/bios_handler.hpp
@@ -4,24 +4,9 @@
 
 #include <stdint.h>
 
+#include <sdbusplus/asio/connection.hpp>
 #include <string>
 
-namespace sdbusplus
-{
-namespace bus
-{
-class bus;
-} // namespace bus
-} // namespace sdbusplus
-
-namespace sdbusplus
-{
-namespace message
-{
-class message;
-} // namespace message
-} // namespace sdbusplus
-
 namespace openpower
 {
 namespace vpd
@@ -55,8 +40,10 @@
     BiosHandler& operator=(BiosHandler&&) = delete;
     ~BiosHandler() = default;
 
-    BiosHandler(sdbusplus::bus_t& bus, Manager& manager) :
-        bus(bus), manager(manager)
+    BiosHandler(std::shared_ptr<sdbusplus::asio::connection>& conn,
+                Manager& manager) :
+        conn(conn),
+        manager(manager)
     {
         checkAndListenPLDMService();
     }
@@ -254,9 +241,9 @@
     void restoreBIOSAttribs();
 
     /**
      * @brief Reference to the bus.
      */
-    sdbusplus::bus_t& bus;
+    std::shared_ptr<sdbusplus::asio::connection>& conn;
 
     /**
      * @brief Reference to the manager.
@@ -254,9 +241,9 @@
 
     /**
-     * @brief Reference to the bus.
+     * @brief Reference to the connection.
      */